ChatImpl class

Implemented types

Constructors

ChatImpl(Jid _jid, Connection _connection)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jid → Jid
no setteroverride
messages ↔ List<Message>?
getter/setter pairoverride
myState ↔ ChatState?
getter/setter pairoverride
newMessageStream → Stream<Message>
no setteroverride
remoteState → ChatState?
no setteroverride
remoteStateStream → Stream<ChatState?>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMessage(Message message) → void
sendMessage(String text) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

TAG ↔ String
getter/setter pair