Message class

Constructors

Message(MessageStanza messageStanza, Jid? to, Jid? from, String? text, DateTime time, {String? stanzaId = '', String? threadId = '', bool isForwarded = false, bool? isDelayed, String? queryId, String? messageId, MessageStanzaType? type, ChatState? chatState})

Properties

chatState → ChatState?
no setter
from ↔ Jid?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDelayed → bool?
no setter
isForwarded → bool?
no setter
messageId → String?
no setter
messageStanza ↔ MessageStanza
getter/setter pair
queryId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stanzaId → String?
no setter
text ↔ String?
getter/setter pair
threadId → String?
no setter
time ↔ DateTime
getter/setter pair
to ↔ Jid?
getter/setter pair
type → MessageStanzaType?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

TAG ↔ String
getter/setter pair

Static Methods

fromStanza(MessageStanza stanza) → Message