MessageArchiveManager class

Constructors

MessageArchiveManager(Connection _connection)

Properties

enabled → bool
no setter
hasExtended → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isQueryByDateSupported → bool
no setter
isQueryByIdSupported → bool
no setter
isQueryByJidSupported → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAll() → void
queryById({String? beforeId, String? afterId, Jid? jid}) → void
queryByTime({DateTime? start, DateTime? end, Jid? jid}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInstance(Connection connection) → MessageArchiveManager

Constants

TAG → const String