MessageStanza class

Inheritance

Constructors

MessageStanza(dynamic id, dynamic type)

Properties

attributes → List<XmppAttribute>
no setterinherited
body ↔ String?
getter/setter pair
children → List<XmppElement>
no setterinherited
fromJid ↔ Jid?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pairinherited
name ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
getter/setter pair
textValue ↔ String?
getter/setter pairinherited
thread ↔ String?
getter/setter pair
toJid ↔ Jid?
getter/setter pairinherited
type ↔ MessageStanzaType?
getter/setter pair

Methods

addAttribute(XmppAttribute attribute) → void
inherited
addChild(XmppElement element) → void
inherited
buildXml() → XmlElement
inherited
buildXmlString() → String
inherited
getAttribute(String? name) → XmppAttribute?
inherited
getChild(String name) → XmppElement?
inherited
getNameSpace() → String?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited