PrivacyLists class

Constructors

PrivacyLists({String? activeList, String? defaultList, List<String>? allPrivacyLists})

Properties

activeList ↔ String?
getter/setter pair
allPrivacyLists ↔ List<String>?
getter/setter pair
defaultList ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited