PrivacyListsManager class

Constructors

PrivacyListsManager(Connection _connection)

Properties

hashCode → int
The hash code for this object.
no setterinherited
listsChangesStream → Stream<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPrivacyList(PrivacyList privacyList) → Future<void>
declineActiveList() → Future<void>
declineDefaultList() → Future<void>
getAllLists() → Future<PrivacyLists>
getListByName(String name) → Future<List<PrivacyListItem>>
isPrivacyListsSupported() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removePrivacyList(String name) → Future<void>
setActiveList(String name) → Future<void>
setDefaultList(String name) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInstance(Connection connection) → PrivacyListsManager